import { request } from '../utils/request'

export function informationList() {
  return request({
    url: '/consumer/staff',
    method: 'GET',
  })
}

export function informationAdd(data: any) {
  return request({
    // url: '/consumer/staff',
    url:'/consumer/staff/V2',
    method: 'POST',
    data
  })
}
export function informationDelete(data: any) {
  return request({
    url: '/consumer/staff/delete',
    method: 'POST',
    data
  })
}
export function dataRecord(id: any) {
  return request({
    url: '/consumer/staff/dataRecord?id=' + id,
    method: 'GET',
  })
}
export function corrigendaApply(data: any) {
  return request({
    url: '/consumer/corrigendaRecord/apply',
    method: 'POST',
    data
  })
}
export function corrigendaList(data: any) {
  return request({
    url: '/consumer/corrigendaRecord/list',
    method: 'POST',
    data
  })
}
export function updateWithDataId(data: any) {
  return request({
    url: '/consumer/staff/updateWithDataId',
    method: 'PUT',
    data
  })
}

export function redDotMarkDeal(id: any) {
  return request({
    url: `/consumer/staff/redDotMarkDeal?dataId=${id}`,
    method: "GET"
  });
}

export function agentApply(data: any) {
  return request({
    url: `/consumer/staff/businessNameAuthenticationApply`,
    method: "POST",
    data
  });
}

export function businessLinkNameList(data: any) {
  return request({
    url: `/consumer/business/businessLinkNameList`,
    method: "GET",
    data
  });
}

